@@ -52,7 +52,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <Qt3DExtras/qmorphphongmaterial.h>
 #include <Qt3DExtras/qspritesheet.h>
 #include <Qt3DExtras/qfirstpersoncameracontroller.h>
@@ -162,19 +162,16 @@ extern SbkConverter **SbkPySide2_Qt3DExtrasTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QNODEPTR_IDX             = 0, // QVector<Qt3DCore::QNode* >
-    SBK_QT3DEXTRAS_QLIST_QOBJECTPTR_IDX                      = 1, // const QList<QObject* > &
-    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QCOMPONENTPTR_IDX        = 2, // QVector<Qt3DCore::QComponent* >
-    SBK_QT3DEXTRAS_QLIST_QBYTEARRAY_IDX                      = 3, // QList<QByteArray >
-    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QATTRIBUTEPTR_IDX      = 4, // QVector<Qt3DRender::QAttribute* >
-    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QENTITYPTR_IDX           = 5, // QVector<Qt3DCore::QEntity* >
-    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QPARAMETERPTR_IDX      = 6, // QVector<Qt3DRender::QParameter* >
-    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QFILTERKEYPTR_IDX      = 7, // QVector<Qt3DRender::QFilterKey* >
-    SBK_QT3DEXTRAS_QVECTOR_QT3DEXTRAS_QSPRITESHEETITEMPTR_IDX = 8, // QVector<Qt3DExtras::QSpriteSheetItem* >
-    SBK_QT3DEXTRAS_QLIST_QVARIANT_IDX                        = 9, // QList<QVariant >
-    SBK_QT3DEXTRAS_QLIST_QSTRING_IDX                         = 10, // QList<QString >
-    SBK_QT3DEXTRAS_QMAP_QSTRING_QVARIANT_IDX                 = 11, // QMap<QString,QVariant >
-    SBK_Qt3DExtras_CONVERTERS_IDX_COUNT                      = 12
+    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QCOMPONENTPTR_IDX        = 0, // QVector<Qt3DCore::QComponent* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DCORE_QNODEPTR_IDX             = 1, // QVector<Qt3DCore::QNode* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QATTRIBUTEPTR_IDX      = 2, // QVector<Qt3DRender::QAttribute* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QPARAMETERPTR_IDX      = 3, // QVector<Qt3DRender::QParameter* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DRENDER_QFILTERKEYPTR_IDX      = 4, // QVector<Qt3DRender::QFilterKey* >
+    SBK_QT3DEXTRAS_QVECTOR_QT3DEXTRAS_QSPRITESHEETITEMPTR_IDX = 5, // QVector<Qt3DExtras::QSpriteSheetItem* >
+    SBK_QT3DEXTRAS_QLIST_QVARIANT_IDX                        = 6, // QList<QVariant >
+    SBK_QT3DEXTRAS_QLIST_QSTRING_IDX                         = 7, // QList<QString >
+    SBK_QT3DEXTRAS_QMAP_QSTRING_QVARIANT_IDX                 = 8, // QMap<QString,QVariant >
+    SBK_Qt3DExtras_CONVERTERS_IDX_COUNT                      = 9
 };
 // Macros for type check
 
