@@ -49,7 +49,7 @@
 // Module Includes
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <QtNetwork/qnetworkconfigmanager.h>
 #include <QtNetwork/qnetworkaccessmanager.h>
 #include <QtNetwork/qsslcertificate.h>
@@ -189,43 +189,45 @@ enum : int {
     SBK_QNETWORKREQUEST_LOADCONTROL_IDX                      = 81,
     SBK_QNETWORKREQUEST_PRIORITY_IDX                         = 82,
     SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX                   = 83,
-    SBK_QNETWORKSESSION_IDX                                  = 84,
-    SBK_QNETWORKSESSION_STATE_IDX                            = 86,
-    SBK_QNETWORKSESSION_SESSIONERROR_IDX                     = 85,
-    SBK_QNETWORKSESSION_USAGEPOLICY_IDX                      = 87,
+    SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX          = 84,
+    SBK_QNETWORKSESSION_IDX                                  = 85,
+    SBK_QNETWORKSESSION_STATE_IDX                            = 87,
+    SBK_QNETWORKSESSION_SESSIONERROR_IDX                     = 86,
+    SBK_QNETWORKSESSION_USAGEPOLICY_IDX                      = 88,
     SBK_QFLAGS_QNETWORKSESSION_USAGEPOLICY_IDX               = 30,
-    SBK_QOCSPRESPONSE_IDX                                    = 89,
-    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 91,
-    SBK_QtNetworkQSSL_IDX                                    = 94,
-    SBK_QSSL_KEYTYPE_IDX                                     = 98,
-    SBK_QSSL_ENCODINGFORMAT_IDX                              = 96,
-    SBK_QSSL_KEYALGORITHM_IDX                                = 97,
-    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 95,
-    SBK_QSSL_SSLPROTOCOL_IDX                                 = 100,
-    SBK_QSSL_SSLOPTION_IDX                                   = 99,
+    SBK_QOCSPRESPONSE_IDX                                    = 90,
+    SBK_QtNetworkQPASSWORDDIGESTOR_IDX                       = 92,
+    SBK_QtNetworkQSSL_IDX                                    = 95,
+    SBK_QSSL_KEYTYPE_IDX                                     = 99,
+    SBK_QSSL_ENCODINGFORMAT_IDX                              = 97,
+    SBK_QSSL_KEYALGORITHM_IDX                                = 98,
+    SBK_QSSL_ALTERNATIVENAMEENTRYTYPE_IDX                    = 96,
+    SBK_QSSL_SSLPROTOCOL_IDX                                 = 101,
+    SBK_QSSL_SSLOPTION_IDX                                   = 100,
     SBK_QFLAGS_QSSL_SSLOPTION_IDX                            = 31,
-    SBK_QSSLCERTIFICATE_IDX                                  = 101,
-    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 102,
-    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 103,
-    SBK_QSSLCIPHER_IDX                                       = 104,
-    SBK_QSSLCONFIGURATION_IDX                                = 105,
-    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 106,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 107,
-    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 108,
-    SBK_QSSLERROR_IDX                                        = 109,
-    SBK_QSSLERROR_SSLERROR_IDX                               = 110,
-    SBK_QSSLKEY_IDX                                          = 111,
-    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 112,
-    SBK_QSSLSOCKET_IDX                                       = 113,
-    SBK_QSSLSOCKET_SSLMODE_IDX                               = 115,
-    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 114,
-    SBK_QTCPSERVER_IDX                                       = 116,
-    SBK_QTCPSOCKET_IDX                                       = 117,
-    SBK_QUDPSOCKET_IDX                                       = 118,
+    SBK_QSSLCERTIFICATE_IDX                                  = 102,
+    SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX                      = 104,
+    SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX                    = 103,
+    SBK_QSSLCERTIFICATEEXTENSION_IDX                         = 105,
+    SBK_QSSLCIPHER_IDX                                       = 106,
+    SBK_QSSLCONFIGURATION_IDX                                = 107,
+    SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX  = 108,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX                      = 109,
+    SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX                = 110,
+    SBK_QSSLERROR_IDX                                        = 111,
+    SBK_QSSLERROR_SSLERROR_IDX                               = 112,
+    SBK_QSSLKEY_IDX                                          = 113,
+    SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX                    = 114,
+    SBK_QSSLSOCKET_IDX                                       = 115,
+    SBK_QSSLSOCKET_SSLMODE_IDX                               = 117,
+    SBK_QSSLSOCKET_PEERVERIFYMODE_IDX                        = 116,
+    SBK_QTCPSERVER_IDX                                       = 118,
+    SBK_QTCPSOCKET_IDX                                       = 119,
+    SBK_QUDPSOCKET_IDX                                       = 120,
     SBK_QDTLSERROR_IDX                                       = 20,
-    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 88,
-    SBK_QOCSPREVOCATIONREASON_IDX                            = 90,
-    SBK_QtNetwork_IDX_COUNT                                  = 119
+    SBK_QOCSPCERTIFICATESTATUS_IDX                           = 89,
+    SBK_QOCSPREVOCATIONREASON_IDX                            = 91,
+    SBK_QtNetwork_IDX_COUNT                                  = 121
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_QtNetworkTypes;
@@ -276,6 +278,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QDtlsError >() { return SbkPySide2_QtNetworkTypes[SBK_QDTLSERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QOcspCertificateStatus >() { return SbkPySide2_QtNetworkTypes[SBK_QOCSPCERTIFICATESTATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QOcspRevocationReason >() { return SbkPySide2_QtNetworkTypes[SBK_QOCSPREVOCATIONREASON_IDX]; }
@@ -359,6 +363,7 @@ template<> inline PyTypeObject *SbkType< ::QNetworkRequest::CacheLoadControl >()
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest::LoadControl >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKREQUEST_LOADCONTROL_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest::Priority >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKREQUEST_PRIORITY_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest::RedirectPolicy >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QNetworkRequest::TransferTimeoutConstant >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QNETWORKREQUEST_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkSession::State >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKSESSION_STATE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkSession::SessionError >() { return SbkPySide2_QtNetworkTypes[SBK_QNETWORKSESSION_SESSIONERROR_IDX]; }
@@ -374,6 +379,7 @@ template<> inline PyTypeObject *SbkType< ::QSsl::SslProtocol >() { return SbkPyS
 template<> inline PyTypeObject *SbkType< ::QSsl::SslOption >() { return SbkPySide2_QtNetworkTypes[SBK_QSSL_SSLOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QSsl::SslOption> >() { return SbkPySide2_QtNetworkTypes[SBK_QFLAGS_QSSL_SSLOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslCertificate::SubjectInfo >() { return SbkPySide2_QtNetworkTypes[SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSslCertificate::PatternSyntax >() { return SbkPySide2_QtNetworkTypes[SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslCertificate >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QSSLCERTIFICATE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSslCertificateExtension >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QSSLCERTIFICATEEXTENSION_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSslCipher >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QSSLCIPHER_IDX]); }
@@ -391,6 +397,7 @@ template<> inline PyTypeObject *SbkType< ::QSslSocket >() { return reinterpret_c
 template<> inline PyTypeObject *SbkType< ::QTcpServer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QTCPSERVER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QTcpSocket >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QTCPSOCKET_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QUdpSocket >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtNetworkTypes[SBK_QUDPSOCKET_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
