@@ -51,7 +51,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <QtOpenGL/qgl.h>
 #include <QtOpenGL/qglbuffer.h>
 #include <QtOpenGL/qglframebufferobject.h>
@@ -130,6 +130,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QGL::FormatOption >() { return SbkPySide2_QtOpenGLTypes[SBK_QGL_FORMATOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QGL::FormatOption> >() { return SbkPySide2_QtOpenGLTypes[SBK_QFLAGS_QGL_FORMATOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QGLBuffer::Type >() { return SbkPySide2_QtOpenGLTypes[SBK_QGLBUFFER_TYPE_IDX]; }
@@ -153,6 +155,7 @@ template<> inline PyTypeObject *SbkType< ::QFlags<QGLShader::ShaderTypeBit> >()
 template<> inline PyTypeObject *SbkType< ::QGLShader >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLSHADER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QGLShaderProgram >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLSHADERPROGRAM_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QGLWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtOpenGLTypes[SBK_QGLWIDGET_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
