@@ -51,7 +51,7 @@
 #include <pyside2_qtnetwork_python.h>
 #include <pyside2_qtgui_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <QtQml/qjsengine.h>
 #include <QtQml/qqmlscriptstring.h>
 #include <QtQml/qqmlextensioninterface.h>
@@ -159,10 +159,10 @@ enum : int {
     SBK_QTQML_QLIST_QBYTEARRAY_IDX                           = 1, // QList<QByteArray >
     SBK_QTQML_QLIST_QJSVALUE_IDX                             = 2, // const QList<QJSValue > &
     SBK_QTQML_QLIST_QQMLERROR_IDX                            = 3, // QList<QQmlError > *
-    SBK_QTQML_QHASH_QSTRING_QVARIANT_IDX                     = 4, // const QHash<QString,QVariant > &
-    SBK_QTQML_QLIST_QVARIANT_IDX                             = 5, // QList<QVariant >
-    SBK_QTQML_QLIST_QSTRING_IDX                              = 6, // QList<QString >
-    SBK_QTQML_QMAP_QSTRING_QVARIANT_IDX                      = 7, // QMap<QString,QVariant >
+    SBK_QTQML_QMAP_QSTRING_QVARIANT_IDX                      = 4, // const QMap<QString,QVariant > &
+    SBK_QTQML_QHASH_QSTRING_QVARIANT_IDX                     = 5, // const QHash<QString,QVariant > &
+    SBK_QTQML_QLIST_QVARIANT_IDX                             = 6, // QList<QVariant >
+    SBK_QTQML_QLIST_QSTRING_IDX                              = 7, // QList<QString >
     SBK_QtQml_CONVERTERS_IDX_COUNT                           = 8
 };
 // Macros for type check
@@ -171,6 +171,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QJSEngine::Extension >() { return SbkPySide2_QtQmlTypes[SBK_QJSENGINE_EXTENSION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QJSEngine::Extension> >() { return SbkPySide2_QtQmlTypes[SBK_QFLAGS_QJSENGINE_EXTENSION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QJSEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QJSENGINE_IDX]); }
@@ -214,6 +216,7 @@ template<> inline PyTypeObject *SbkType< ::QQmlPropertyMap >() { return reinterp
 template<> inline PyTypeObject *SbkType< ::QQmlPropertyValueSource >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLPROPERTYVALUESOURCE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlScriptString >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLSCRIPTSTRING_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQmlTypesExtensionInterface >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQmlTypes[SBK_QQMLTYPESEXTENSIONINTERFACE_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
