@@ -52,7 +52,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtwidgets_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <QtScriptTools/qscriptenginedebugger.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
@@ -104,10 +104,13 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QScriptEngineDebugger::DebuggerWidget >() { return SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERWIDGET_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QScriptEngineDebugger::DebuggerAction >() { return SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERACTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QScriptEngineDebugger::DebuggerState >() { return SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_DEBUGGERSTATE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QScriptEngineDebugger >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtScriptToolsTypes[SBK_QSCRIPTENGINEDEBUGGER_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
